' This is file scan_image.bas
'
' a FreeBasic translation of file scan_image.c from zbar library
' GPL-3 (C) 2013 by Thomas[ dot ]Freiherr[ at ]gmx[ dot ]net
'
' For details see
' http://zbar.sourceforge.net
'
' * load image
' * scan for codes
' * output decoded results to stdout
'
' Compile source with
'   fbc scan_image.bas
' and execute with png filename as parameter, like
'   ./scan_image qr1.png

#INCLUDE ONCE "png.bi"
#INCLUDE ONCE "zbar/zbar.bi"

'/* to complete a runnable example, this abbreviated implementation of
 '* get_data() will use libpng to read an image file. refer to libpng
 '* documentation for details
 '*/
FUNCTION get_data( _
  BYVAL Nam AS ZSTRING PTR, _
  BYVAL W AS INTEGER PTR, _
  BYVAL H AS INTEGER PTR) AS ANY PTR

  VAR file = fopen(Nam, "rb")
  IF 0 = file THEN ?"Couldn't open file!" : END 2
  VAR png = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL)
  IF 0 = png THEN ?"Couldn't create read struct!" : END 3
  IF setjmp(png_jmpbuf(png)) THEN ?"Error setjmp!" : END 4
  VAR info = png_create_info_struct(png)
  IF 0 = info THEN ?"Couldn't get file info!" : END 5

  png_init_io(png, file)
  png_read_info(png, info)

  '/* configure for 8bpp grayscale input */
  VAR colr = png_get_color_type(png, info)
  VAR bits = png_get_bit_depth(png, info)
  IF colr AND PNG_COLOR_TYPE_PALETTE THEN png_set_palette_to_rgb(png)
  IF colr = PNG_COLOR_TYPE_GRAY ANDALSO bits < 8 THEN png_set_gray_1_2_4_to_8(png)
  IF bits = 16 THEN png_set_strip_16(png)
  IF colr AND PNG_COLOR_MASK_ALPHA THEN png_set_strip_alpha(png)
  IF colr AND PNG_COLOR_MASK_COLOR THEN png_set_rgb_to_gray_fixed(png, 1, -1, -1)

  '/* allocate image */
  *W = png_get_image_width(png, info)
  *H = png_get_image_height(png, info)
  VAR r = ALLOCATE(*W * *H)
  IF 0 = r THEN ?"Couldn't allocate memory!" : END 6

  DIM AS png_bytep rows(*H - 1)
  FOR i AS INTEGER = 0 TO *H - 1
    rows(i) = r + (*W * i)
  NEXT
  png_read_image(png, @rows(0))
  RETURN r
END FUNCTION


' ***** main *****
IF __FB_ARGC__ < 2 THEN ?"Pass file name as parameter!" : END 1

'/* create a reader */
VAR scanner = zbar_image_scanner_create()

'/* configure the reader */
zbar_image_scanner_set_config(scanner, 0, ZBAR_CFG_ENABLE, 1)

'/* obtain image data */
VAR width_ = 0, height = 0
VAR raw = get_data(__FB_ARGV__[1], @width_, @height)

'/* wrap image data */
VAR image = zbar_image_create()
zbar_image_set_format(image, *CAST(UINTEGER PTR, @"Y800"))
zbar_image_set_size(image, width_, height)
zbar_image_set_data(image, raw, width_ * height, @zbar_image_free_data)

'/* scan the image for barcodes */
VAR n = zbar_scan_image(scanner, image)

'/* extract results */
VAR symbol = zbar_image_first_symbol(image)
WHILE symbol
  '/* do something useful with results */
  VAR typ = zbar_symbol_get_type(symbol)
  VAR dat_ = zbar_symbol_get_data(symbol)
  PRINT "decoded " & *zbar_get_symbol_name(typ) & " symbol """ & *dat_ & """"
  symbol = zbar_symbol_next(symbol)
WEND

'/* clean up */
zbar_image_destroy(image)
zbar_image_scanner_destroy(scanner)

