' This is file test_gtk.bas
'
' a FreeBasic translation of file test_gtk.c from zbar library
' GPL-3 (C) 2013 by Thomas[ dot ]Freiherr[ at ]gmx[ dot ]net
'
' Original licence text:
'/*------------------------------------------------------------------------
 '*  Copyright 2009 (c) Jeff Brown <spadix@users.sourceforge.net>
 '*
 '*  This file is part of the ZBar Bar Code Reader.
 '*
 '*  The ZBar Bar Code Reader is free software; you can redistribute it
 '*  and/or modify it under the terms of the GNU Lesser Public License as
 '*  published by the Free Software Foundation; either version 2.1 of
 '*  the License, or (at your option) any later version.
 '*
 '*  The ZBar Bar Code Reader is distributed in the hope that it will be
 '*  useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 '*  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 '*  GNU Lesser Public License for more details.
 '*
 '*  You should have received a copy of the GNU Lesser Public License
 '*  along with the ZBar Bar Code Reader; if not, write to the Free
 '*  Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 '*  Boston, MA  02110-1301  USA
 '*
 '*  http://sourceforge.net/projects/zbar
 '*------------------------------------------------------------------------*/

#INCLUDE ONCE "zbar/zbargtk.bi"

DIM SHARED AS GtkWidget PTR WIN = NULL, STATUS_IMAGE = NULL
DIM SHARED AS GtkTextView PTR RESULTS = NULL
DIM SHARED AS gchar PTR OPEN_FILE = NULL

'/* decode signal callback
 '* puts the decoded result in the textbox
 '*/
SUB decoded( _
  BYVAL Widget AS GtkWidget PTR, _
  BYVAL Symbol AS zbar_symbol_type_t, _
  BYVAL Result AS CONST ZSTRING PTR, _
  BYVAL Dat AS gpointer)

  VAR resultbuf = gtk_text_view_get_buffer(RESULTS)
  DIM AS GtkTextIter last
  gtk_text_buffer_get_end_iter(resultbuf, @last)
  gtk_text_buffer_insert(resultbuf, @last, zbar_get_symbol_name(Symbol), -1)
  gtk_text_buffer_insert(resultbuf, @last, zbar_get_addon_name(Symbol), -1)
  gtk_text_buffer_insert(resultbuf, @last, ": ", -1)
  gtk_text_buffer_insert(resultbuf, @last, Result, -1)
  gtk_text_buffer_insert(resultbuf, @last, !"\n", -1)
  gtk_text_view_scroll_to_iter(RESULTS, @last, 0, FALSE, 0, 0)
  gdk_beep()
END SUB


'/* update botton state when video state changes */
SUB video_enabled( _
  BYVAL Obj AS GObject PTR, _
  BYVAL Param AS GParamSpec PTR, _
  BYVAL Dat AS gpointer)

  VAR zbar = ZBAR_GTK(Obj)
  VAR enabled = zbar_gtk_get_video_enabled(zbar)
  VAR opened = zbar_gtk_get_video_opened(zbar)

  VAR button = GTK_TOGGLE_BUTTON(Dat)
  VAR active = gtk_toggle_button_get_active(button)
  IF active <> (opened ANDALSO enabled) THEN gtk_toggle_button_set_active(button, enabled)
END SUB

SUB video_opened( _
  BYVAL Obj AS GObject PTR, _
  BYVAL Param AS GParamSpec PTR, _
  BYVAL Dat AS gpointer)

  VAR zbar = ZBAR_GTK(Obj)
  VAR opened = zbar_gtk_get_video_opened(zbar)
  VAR enabled = zbar_gtk_get_video_enabled(zbar)

  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(Dat), opened ANDALSO enabled)
  gtk_widget_set_sensitive(GTK_WIDGET(Dat), opened)
END SUB

'/* (re)open the video when a new device is selected */
SUB video_changed( _
  BYVAL Widget AS GtkWidget PTR, _
  BYVAL Dat AS gpointer)

  VAR video_device = gtk_combo_box_get_active_text(GTK_COMBO_BOX(Widget))
  zbar_gtk_set_video_device( _
    ZBAR_GTK(Dat), _
    IIF(video_device ANDALSO video_device[0] <> ASC("<"), video_device, NULL))
END SUB

SUB status_button_toggled(BYVAL Button AS GtkToggleButton PTR, BYVAL Dat AS gpointer)
  VAR zbar = ZBAR_GTK(Dat)
  VAR opened = zbar_gtk_get_video_opened(zbar)
  VAR enabled = zbar_gtk_get_video_enabled(zbar)
  VAR active = gtk_toggle_button_get_active(button)
  IF opened ANDALSO (active <> enabled) THEN zbar_gtk_set_video_enabled(zbar, active)
  gtk_image_set_from_stock(GTK_IMAGE(STATUS_IMAGE), _
                           IIF(opened ANDALSO active, @GTK_STOCK_YES, @GTK_STOCK_NO), _
                           GTK_ICON_SIZE_BUTTON)
  gtk_button_set_label(GTK_BUTTON(Button), _
                       IIF(0 = opened, @"closed", IIF(active, @"enabled", @"disabled")))
END SUB

SUB open_button_clicked(BYVAL Button AS GtkButton PTR, BYVAL Dat AS gpointer)
  VAR dialog = _
      gtk_file_chooser_dialog_new("Load Image File", GTK_WINDOW(WIN), _
                                  GTK_FILE_CHOOSER_ACTION_OPEN, _
                                  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, _
                                  GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, _
                                  NULL)
  VAR chooser = GTK_FILE_CHOOSER(dialog)
  IF OPEN_FILE THEN _
      gtk_file_chooser_set_filename(chooser, OPEN_FILE)

  IF gtk_dialog_run(GTK_DIALOG(dialog)) = GTK_RESPONSE_ACCEPT THEN
      VAR file = gtk_file_chooser_get_filename(chooser)
      VAR pixbuf = gdk_pixbuf_new_from_file(file, NULL)
      IF pixbuf THEN
          zbar_gtk_scan_image(ZBAR_GTK(Dat), pixbuf)
      ELSE
          fprintf(stderr, !"ERROR: unable to open image file: %s\n", file)
      END IF

      IF OPEN_FILE ANDALSO file THEN g_free(OPEN_FILE)
      OPEN_FILE = file
  END IF
  gtk_widget_destroy(dialog)
END SUB


TYPE cb_t AS SUB CDECL(BYVAL AS GtkComboBoxText PTR, BYVAL AS CONST ZSTRING PTR)

'/* looks for a specified "default" device (if not NULL),
 '* otherwise scan /dev for video devices and call add_device for each.
 '*/
FUNCTION scan_video( _
  BYVAL Add_Device AS cb_t, _
  BYVAL Dat AS ANY PTR, _
  BYVAL Default_Device AS CONST ZSTRING PTR) AS INTEGER

  IF Default_Device THEN Add_Device(Dat, Default_Device) : RETURN 1

  DIM AS GError PTR errr
  VAR r = 0, fold = g_dir_open("/dev", 0, @errr)
  IF fold THEN
    VAR pat = g_pattern_spec_new("video*") '                 scan folder
    VAR nam = g_dir_read_name(fold)
    WHILE nam
      IF g_pattern_match_string(pat, nam) _
        THEN Add_Device(Dat, "/dev/" & *nam) : r += 1
      nam = g_dir_read_name(fold)
    WEND
    g_pattern_spec_free(pat)
    g_dir_close(fold)
  END IF : RETURN r
END FUNCTION

'/* build a simple gui w/:
 '*   - a combo box to select the desired video device
 '*   - the zbar widget to display video
 '*   - a non-editable text box to display any results
 '*/
'***** main *****
gdk_threads_init()
gdk_threads_enter()

gtk_init(@__FB_ARGC__, @__FB_ARGV__)
DIM AS CONST gchar PTR video_arg = NULL

IF __FB_ARGC__ > 1 THEN video_arg = __FB_ARGV__[1]

WIN = gtk_window_new(GTK_WINDOW_TOPLEVEL)

gtk_window_set_title(GTK_WINDOW(WIN), "test_gtk")
gtk_container_set_border_width(GTK_CONTAINER(WIN), 8)

g_signal_connect(G_OBJECT(WIN), "destroy", G_CALLBACK(@gtk_main_quit), NULL)

VAR zbar = zbar_gtk_new()

g_signal_connect(G_OBJECT(zbar), "decoded", G_CALLBACK(@decoded), NULL)

'/* video device list combo box */
VAR video_list = gtk_combo_box_text_new()

g_signal_connect(G_OBJECT(video_list), "changed", G_CALLBACK(@video_changed), zbar)

'/* enable/disable status button */
VAR status_button = gtk_toggle_button_new()
STATUS_IMAGE = gtk_image_new_from_stock(GTK_STOCK_NO, GTK_ICON_SIZE_BUTTON)
gtk_button_set_image(GTK_BUTTON(status_button), STATUS_IMAGE)
gtk_button_set_label(GTK_BUTTON(status_button), "closed")
gtk_widget_set_sensitive(status_button, FALSE)

'/* bind status button state and video state */
g_signal_connect(G_OBJECT(status_button), "toggled", G_CALLBACK(@status_button_toggled), zbar)
g_signal_connect(G_OBJECT(zbar), "notify::video-enabled", G_CALLBACK(@video_enabled), status_button)
g_signal_connect(G_OBJECT(zbar), "notify::video-opened", G_CALLBACK(@video_opened), status_button)

'/* open image file button */
VAR open_button = gtk_button_new_from_stock(GTK_STOCK_OPEN)

g_signal_connect(G_OBJECT(open_button), "clicked", G_CALLBACK(@open_button_clicked), zbar)

gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(video_list), "<none>")
VAR active = scan_video(@gtk_combo_box_text_append_text, video_list, video_arg)
IF active >= 0 THEN gtk_combo_box_set_active(GTK_COMBO_BOX(video_list), active)

'/* hbox for combo box and buttons */
VAR hbox = gtk_hbox_new(FALSE, 8)

gtk_box_pack_start(GTK_BOX(hbox), video_list, TRUE, TRUE, 0)
gtk_box_pack_start(GTK_BOX(hbox), status_button, FALSE, FALSE, 0)
gtk_box_pack_start(GTK_BOX(hbox), open_button, FALSE, FALSE, 0)

'/* text box for holding results */
RESULTS = GTK_TEXT_VIEW(gtk_text_view_new())
gtk_widget_set_size_request(GTK_WIDGET(RESULTS), 320, 64)
gtk_text_view_set_editable(RESULTS, FALSE)
gtk_text_view_set_cursor_visible(RESULTS, FALSE)
gtk_text_view_set_left_margin(RESULTS, 4)

'/* vbox for hbox, zbar test widget and result text box */
VAR vbox = gtk_vbox_new(FALSE, 8)
gtk_container_add(GTK_CONTAINER(WIN), vbox)

gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0)
gtk_box_pack_start(GTK_BOX(vbox), zbar, TRUE, TRUE, 0)
gtk_box_pack_start(GTK_BOX(vbox), GTK_WIDGET(RESULTS), FALSE, FALSE, 0)

DIM AS GdkGeometry hints
hints.min_width = 320
hints.min_height = 240
gtk_window_set_geometry_hints(GTK_WINDOW(WIN), zbar, @hints, GDK_HINT_MIN_SIZE)

gtk_widget_show_all(WIN)
gtk_main()
gdk_threads_leave()
