#IFDEF __FB_WIN32__
#PRAGMA push(msbitfields)
EXTERN "C" LIB "zbar-0"
#ELSE
EXTERN "C" LIB "zbar"
#ENDIF

#IFNDEF _ZBAR_H_
#DEFINE _ZBAR_H_

ENUM zbar_color_e
	ZBAR_SPACE = 0
	ZBAR_BAR = 1
END ENUM

TYPE zbar_color_t AS zbar_color_e

ENUM zbar_symbol_type_e
	ZBAR_NONE = 0
	ZBAR_PARTIAL = 1
	ZBAR_EAN8 = 8
	ZBAR_UPCE = 9
	ZBAR_ISBN10 = 10
	ZBAR_UPCA = 12
	ZBAR_EAN13 = 13
	ZBAR_ISBN13 = 14
	ZBAR_I25 = 25
	ZBAR_CODE39 = 39
	ZBAR_PDF417 = 57
	ZBAR_QRCODE = 64
	ZBAR_CODE128 = 128
	ZBAR_SYMBOL = &h00FF
	ZBAR_ADDON2 = &h0200
	ZBAR_ADDON5 = &h0500
	ZBAR_ADDON = &h0700
END ENUM

TYPE zbar_symbol_type_t AS zbar_symbol_type_e

ENUM zbar_error_e
	ZBAR_OK = 0
	ZBAR_ERR_NOMEM
	ZBAR_ERR_INTERNAL
	ZBAR_ERR_UNSUPPORTED
	ZBAR_ERR_INVALID
	ZBAR_ERR_SYSTEM
	ZBAR_ERR_LOCKING
	ZBAR_ERR_BUSY
	ZBAR_ERR_XDISPLAY
	ZBAR_ERR_XPROTO
	ZBAR_ERR_CLOSED
	ZBAR_ERR_WINAPI
	ZBAR_ERR_NUM
END ENUM

TYPE zbar_error_t AS zbar_error_e

ENUM zbar_config_e
	ZBAR_CFG_ENABLE = 0
	ZBAR_CFG_ADD_CHECK
	ZBAR_CFG_EMIT_CHECK
	ZBAR_CFG_ASCII
	ZBAR_CFG_NUM
	ZBAR_CFG_MIN_LEN = &h20
	ZBAR_CFG_MAX_LEN
	ZBAR_CFG_POSITION = &h80
	ZBAR_CFG_X_DENSITY = &h100
	ZBAR_CFG_Y_DENSITY
END ENUM

TYPE zbar_config_t AS zbar_config_e

DECLARE FUNCTION zbar_version(BYVAL AS UINTEGER PTR, BYVAL AS UINTEGER PTR) AS INTEGER
DECLARE SUB zbar_set_verbosity(BYVAL AS INTEGER)
DECLARE SUB zbar_increase_verbosity()
DECLARE FUNCTION zbar_get_symbol_name(BYVAL AS zbar_symbol_type_t) AS CONST ZSTRING PTR
DECLARE FUNCTION zbar_get_addon_name(BYVAL AS zbar_symbol_type_t) AS CONST ZSTRING PTR
DECLARE FUNCTION zbar_parse_config(BYVAL AS CONST ZSTRING PTR, BYVAL AS zbar_symbol_type_t PTR, BYVAL AS zbar_config_t PTR, BYVAL AS INTEGER PTR) AS INTEGER
DECLARE FUNCTION _zbar_error_spew(BYVAL AS CONST ANY PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION _zbar_error_string(BYVAL AS CONST ANY PTR, BYVAL AS INTEGER) AS CONST ZSTRING PTR
DECLARE FUNCTION _zbar_get_error_code(BYVAL AS CONST ANY PTR) AS zbar_error_t

' struct zbar_symbol_s;
TYPE zbar_symbol_s AS ANY PTR
TYPE zbar_symbol_t AS zbar_symbol_s

' struct zbar_symbol_set_s;
TYPE zbar_symbol_set_s AS ANY PTR
TYPE zbar_symbol_set_t AS zbar_symbol_set_s

DECLARE SUB zbar_symbol_ref(BYVAL AS CONST zbar_symbol_t PTR, BYVAL AS INTEGER)
DECLARE FUNCTION zbar_symbol_get_type(BYVAL AS CONST zbar_symbol_t PTR) AS zbar_symbol_type_t
DECLARE FUNCTION zbar_symbol_get_data(BYVAL AS CONST zbar_symbol_t PTR) AS CONST ZSTRING PTR
DECLARE FUNCTION zbar_symbol_get_data_length(BYVAL AS CONST zbar_symbol_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_symbol_get_quality(BYVAL AS CONST zbar_symbol_t PTR) AS INTEGER
DECLARE FUNCTION zbar_symbol_get_count(BYVAL AS CONST zbar_symbol_t PTR) AS INTEGER
DECLARE FUNCTION zbar_symbol_get_loc_size(BYVAL AS CONST zbar_symbol_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_symbol_get_loc_x(BYVAL AS CONST zbar_symbol_t PTR, BYVAL AS UINTEGER) AS INTEGER
DECLARE FUNCTION zbar_symbol_get_loc_y(BYVAL AS CONST zbar_symbol_t PTR, BYVAL AS UINTEGER) AS INTEGER
DECLARE FUNCTION zbar_symbol_next(BYVAL AS CONST zbar_symbol_t PTR) AS CONST zbar_symbol_t PTR
DECLARE FUNCTION zbar_symbol_get_components(BYVAL AS CONST zbar_symbol_t PTR) AS CONST zbar_symbol_set_t PTR
DECLARE FUNCTION zbar_symbol_first_component(BYVAL AS CONST zbar_symbol_t PTR) AS CONST zbar_symbol_t PTR
DECLARE FUNCTION zbar_symbol_xml(BYVAL AS CONST zbar_symbol_t PTR, BYVAL AS ZSTRING PTR PTR, BYVAL AS UINTEGER PTR) AS ZSTRING PTR
DECLARE SUB zbar_symbol_set_ref(BYVAL AS CONST zbar_symbol_set_t PTR, BYVAL AS INTEGER)
DECLARE FUNCTION zbar_symbol_set_get_size(BYVAL AS CONST zbar_symbol_set_t PTR) AS INTEGER
DECLARE FUNCTION zbar_symbol_set_first_symbol(BYVAL AS CONST zbar_symbol_set_t PTR) AS CONST zbar_symbol_t PTR

' struct zbar_image_s;
TYPE zbar_image_s AS ANY PTR
TYPE zbar_image_t AS zbar_image_s
TYPE zbar_image_cleanup_handler_t AS SUB(BYVAL AS zbar_image_t PTR)
TYPE zbar_image_data_handler_t AS SUB(BYVAL AS zbar_image_t PTR, BYVAL AS CONST ANY PTR)

DECLARE FUNCTION zbar_image_create() AS zbar_image_t PTR
DECLARE SUB zbar_image_destroy(BYVAL AS zbar_image_t PTR)
DECLARE SUB zbar_image_ref(BYVAL AS zbar_image_t PTR, BYVAL AS INTEGER)
DECLARE FUNCTION zbar_image_convert(BYVAL AS CONST zbar_image_t PTR, BYVAL AS UINTEGER) AS zbar_image_t PTR
DECLARE FUNCTION zbar_image_convert_resize(BYVAL AS CONST zbar_image_t PTR, BYVAL AS UINTEGER, BYVAL AS UINTEGER, BYVAL AS UINTEGER) AS zbar_image_t PTR
DECLARE FUNCTION zbar_image_get_format(BYVAL AS CONST zbar_image_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_image_get_sequence(BYVAL AS CONST zbar_image_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_image_get_width(BYVAL AS CONST zbar_image_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_image_get_height(BYVAL AS CONST zbar_image_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_image_get_data(BYVAL AS CONST zbar_image_t PTR) AS CONST ANY PTR
DECLARE FUNCTION zbar_image_get_data_length(BYVAL AS CONST zbar_image_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_image_get_symbols(BYVAL AS CONST zbar_image_t PTR) AS CONST zbar_symbol_set_t PTR
DECLARE SUB zbar_image_set_symbols(BYVAL AS zbar_image_t PTR, BYVAL AS CONST zbar_symbol_set_t PTR)
DECLARE FUNCTION zbar_image_first_symbol(BYVAL AS CONST zbar_image_t PTR) AS CONST zbar_symbol_t PTR
DECLARE SUB zbar_image_set_format(BYVAL AS zbar_image_t PTR, BYVAL AS UINTEGER)
DECLARE SUB zbar_image_set_sequence(BYVAL AS zbar_image_t PTR, BYVAL AS UINTEGER)
DECLARE SUB zbar_image_set_size(BYVAL AS zbar_image_t PTR, BYVAL AS UINTEGER, BYVAL AS UINTEGER)
DECLARE SUB zbar_image_set_data(BYVAL AS zbar_image_t PTR, BYVAL AS CONST ANY PTR, BYVAL AS UINTEGER, BYVAL AS zbar_image_cleanup_handler_t)
DECLARE SUB zbar_image_free_data(BYVAL AS zbar_image_t PTR)
DECLARE SUB zbar_image_set_userdata(BYVAL AS zbar_image_t PTR, BYVAL AS ANY PTR)
DECLARE FUNCTION zbar_image_get_userdata(BYVAL AS CONST zbar_image_t PTR) AS ANY PTR
DECLARE FUNCTION zbar_image_write(BYVAL AS CONST zbar_image_t PTR, BYVAL AS CONST ZSTRING PTR) AS INTEGER
DECLARE FUNCTION zbar_image_read(BYVAL AS ZSTRING PTR) AS zbar_image_t PTR

' struct zbar_processor_s;
TYPE zbar_processor_s AS ANY PTR
TYPE zbar_processor_t AS zbar_processor_s

DECLARE FUNCTION zbar_processor_create(BYVAL AS INTEGER) AS zbar_processor_t PTR
DECLARE SUB zbar_processor_destroy(BYVAL AS zbar_processor_t PTR)
DECLARE FUNCTION zbar_processor_init(BYVAL AS zbar_processor_t PTR, BYVAL AS CONST ZSTRING PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_processor_request_size(BYVAL AS zbar_processor_t PTR, BYVAL AS UINTEGER, BYVAL AS UINTEGER) AS INTEGER
DECLARE FUNCTION zbar_processor_request_interface(BYVAL AS zbar_processor_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_processor_request_iomode(BYVAL AS zbar_processor_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_processor_force_format(BYVAL AS zbar_processor_t PTR, BYVAL AS UINTEGER, BYVAL AS UINTEGER) AS INTEGER
DECLARE FUNCTION zbar_processor_set_data_handler(BYVAL AS zbar_processor_t PTR, BYVAL AS zbar_image_data_handler_t, BYVAL AS CONST ANY PTR) AS zbar_image_data_handler_t
DECLARE SUB zbar_processor_set_userdata(BYVAL AS zbar_processor_t PTR, BYVAL AS ANY PTR)
DECLARE FUNCTION zbar_processor_get_userdata(BYVAL AS CONST zbar_processor_t PTR) AS ANY PTR
DECLARE FUNCTION zbar_processor_set_config(BYVAL AS zbar_processor_t PTR, BYVAL AS zbar_symbol_type_t, BYVAL AS zbar_config_t, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_processor_is_visible(BYVAL AS zbar_processor_t PTR) AS INTEGER
DECLARE FUNCTION zbar_processor_set_visible(BYVAL AS zbar_processor_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_processor_set_active(BYVAL AS zbar_processor_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_processor_get_results(BYVAL AS CONST zbar_processor_t PTR) AS CONST zbar_symbol_set_t PTR
DECLARE FUNCTION zbar_processor_user_wait(BYVAL AS zbar_processor_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_process_one(BYVAL AS zbar_processor_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_process_image(BYVAL AS zbar_processor_t PTR, BYVAL AS zbar_image_t PTR) AS INTEGER

' struct zbar_video_s;
TYPE zbar_video_s AS ANY PTR
TYPE zbar_video_t AS zbar_video_s

DECLARE FUNCTION zbar_video_create() AS zbar_video_t PTR
DECLARE SUB zbar_video_destroy(BYVAL AS zbar_video_t PTR)
DECLARE FUNCTION zbar_video_open(BYVAL AS zbar_video_t PTR, BYVAL AS CONST ZSTRING PTR) AS INTEGER
DECLARE FUNCTION zbar_video_get_fd(BYVAL AS CONST zbar_video_t PTR) AS INTEGER
DECLARE FUNCTION zbar_video_request_size(BYVAL AS zbar_video_t PTR, BYVAL AS UINTEGER, BYVAL AS UINTEGER) AS INTEGER
DECLARE FUNCTION zbar_video_request_interface(BYVAL AS zbar_video_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_video_request_iomode(BYVAL AS zbar_video_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_video_get_width(BYVAL AS CONST zbar_video_t PTR) AS INTEGER
DECLARE FUNCTION zbar_video_get_height(BYVAL AS CONST zbar_video_t PTR) AS INTEGER
DECLARE FUNCTION zbar_video_init(BYVAL AS zbar_video_t PTR, BYVAL AS UINTEGER) AS INTEGER
DECLARE FUNCTION zbar_video_enable(BYVAL AS zbar_video_t PTR, BYVAL AS INTEGER) AS INTEGER
DECLARE FUNCTION zbar_video_next_image(BYVAL AS zbar_video_t PTR) AS zbar_image_t PTR

' struct zbar_window_s;
TYPE zbar_window_s AS ANY PTR
TYPE zbar_window_t AS zbar_window_s

DECLARE FUNCTION zbar_window_create() AS zbar_window_t PTR
DECLARE SUB zbar_window_destroy(BYVAL AS zbar_window_t PTR)
DECLARE FUNCTION zbar_window_attach(BYVAL AS zbar_window_t PTR, BYVAL AS ANY PTR, BYVAL AS UINTEGER) AS INTEGER
DECLARE SUB zbar_window_set_overlay(BYVAL AS zbar_window_t PTR, BYVAL AS INTEGER)
DECLARE FUNCTION zbar_window_get_overlay(BYVAL AS CONST zbar_window_t PTR) AS INTEGER
DECLARE FUNCTION zbar_window_draw(BYVAL AS zbar_window_t PTR, BYVAL AS zbar_image_t PTR) AS INTEGER
DECLARE FUNCTION zbar_window_redraw(BYVAL AS zbar_window_t PTR) AS INTEGER
DECLARE FUNCTION zbar_window_resize(BYVAL AS zbar_window_t PTR, BYVAL AS UINTEGER, BYVAL AS UINTEGER) AS INTEGER
DECLARE FUNCTION zbar_negotiate_format(BYVAL AS zbar_video_t PTR, BYVAL AS zbar_window_t PTR) AS INTEGER

' struct zbar_image_scanner_s;
TYPE zbar_image_scanner_s AS ANY PTR
TYPE zbar_image_scanner_t AS zbar_image_scanner_s

DECLARE FUNCTION zbar_image_scanner_create() AS zbar_image_scanner_t PTR
DECLARE SUB zbar_image_scanner_destroy(BYVAL AS zbar_image_scanner_t PTR)
DECLARE FUNCTION zbar_image_scanner_set_data_handler(BYVAL AS zbar_image_scanner_t PTR, BYVAL AS zbar_image_data_handler_t, BYVAL AS CONST ANY PTR) AS zbar_image_data_handler_t
DECLARE FUNCTION zbar_image_scanner_set_config(BYVAL AS zbar_image_scanner_t PTR, BYVAL AS zbar_symbol_type_t, BYVAL AS zbar_config_t, BYVAL AS INTEGER) AS INTEGER
DECLARE SUB zbar_image_scanner_enable_cache(BYVAL AS zbar_image_scanner_t PTR, BYVAL AS INTEGER)
DECLARE SUB zbar_image_scanner_recycle_image(BYVAL AS zbar_image_scanner_t PTR, BYVAL AS zbar_image_t PTR)
DECLARE FUNCTION zbar_image_scanner_get_results(BYVAL AS CONST zbar_image_scanner_t PTR) AS CONST zbar_symbol_set_t PTR
DECLARE FUNCTION zbar_scan_image(BYVAL AS zbar_image_scanner_t PTR, BYVAL AS zbar_image_t PTR) AS INTEGER

' struct zbar_decoder_s;
TYPE zbar_decoder_s AS ANY PTR
TYPE zbar_decoder_t AS zbar_decoder_s
TYPE zbar_decoder_handler_t AS SUB(BYVAL AS zbar_decoder_t PTR)

DECLARE FUNCTION zbar_decoder_create() AS zbar_decoder_t PTR
DECLARE SUB zbar_decoder_destroy(BYVAL AS zbar_decoder_t PTR)
DECLARE FUNCTION zbar_decoder_set_config(BYVAL AS zbar_decoder_t PTR, BYVAL AS zbar_symbol_type_t, BYVAL AS zbar_config_t, BYVAL AS INTEGER) AS INTEGER
DECLARE SUB zbar_decoder_reset(BYVAL AS zbar_decoder_t PTR)
DECLARE SUB zbar_decoder_new_scan(BYVAL AS zbar_decoder_t PTR)
DECLARE FUNCTION zbar_decode_width(BYVAL AS zbar_decoder_t PTR, BYVAL AS UINTEGER) AS zbar_symbol_type_t
DECLARE FUNCTION zbar_decoder_get_color(BYVAL AS CONST zbar_decoder_t PTR) AS zbar_color_t
DECLARE FUNCTION zbar_decoder_get_data(BYVAL AS CONST zbar_decoder_t PTR) AS CONST ZSTRING PTR
DECLARE FUNCTION zbar_decoder_get_data_length(BYVAL AS CONST zbar_decoder_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_decoder_get_type(BYVAL AS CONST zbar_decoder_t PTR) AS zbar_symbol_type_t
DECLARE FUNCTION zbar_decoder_set_handler(BYVAL AS zbar_decoder_t PTR, BYVAL AS zbar_decoder_handler_t) AS zbar_decoder_handler_t
DECLARE SUB zbar_decoder_set_userdata(BYVAL AS zbar_decoder_t PTR, BYVAL AS ANY PTR)
DECLARE FUNCTION zbar_decoder_get_userdata(BYVAL AS CONST zbar_decoder_t PTR) AS ANY PTR

' struct zbar_scanner_s;
TYPE zbar_scanner_s AS ANY PTR
TYPE zbar_scanner_t AS zbar_scanner_s

DECLARE FUNCTION zbar_scanner_create(BYVAL AS zbar_decoder_t PTR) AS zbar_scanner_t PTR
DECLARE SUB zbar_scanner_destroy(BYVAL AS zbar_scanner_t PTR)
DECLARE FUNCTION zbar_scanner_reset(BYVAL AS zbar_scanner_t PTR) AS zbar_symbol_type_t
DECLARE FUNCTION zbar_scanner_new_scan(BYVAL AS zbar_scanner_t PTR) AS zbar_symbol_type_t
DECLARE FUNCTION zbar_scanner_flush(BYVAL AS zbar_scanner_t PTR) AS zbar_symbol_type_t
DECLARE FUNCTION zbar_scan_y(BYVAL AS zbar_scanner_t PTR, BYVAL AS INTEGER) AS zbar_symbol_type_t
DECLARE FUNCTION zbar_scanner_get_width(BYVAL AS CONST zbar_scanner_t PTR) AS UINTEGER
DECLARE FUNCTION zbar_scanner_get_edge(BYVAL AS CONST zbar_scanner_t PTR, BYVAL AS UINTEGER, BYVAL AS INTEGER) AS UINTEGER
DECLARE FUNCTION zbar_scanner_get_color(BYVAL AS CONST zbar_scanner_t PTR) AS zbar_color_t

#ENDIF ' _ZBAR_H_

END EXTERN

#IFDEF __FB_WIN32__
#PRAGMA pop(msbitfields)
#ENDIF

' Translated at 13-05-11 20:41:43, by h_2_bi (version 0.2.3,
' released under GPLv3 by Thomas[ dot ]Freiherr{ at }gmx[ dot ]net)

'   Protocol: zbar.bi
' Parameters: 
'                                  Process time [s]: 0.1273110184120014
'                                  Bytes translated: 20936
'                                      Maximum deep: 2
'                                SUB/FUNCTION names: 121
'                                mangled TYPE names: 0
'                                        files done: 1
' zbar-0.10/include/zbar.h
'                                      files missed: 0
'                                       __FOLDERS__: 1
' zbar-0.10/include/
'                                        __MACROS__: 1
' 118: #define extern
'                                       __HEADERS__: 0
'                                         __TYPES__: 0
'                                     __POST_REPS__: 0
